from django.db import models
#from ckeditor.fields import RichTextField

from ckeditor_uploader.fields import RichTextUploadingField

# Create your models here.



class VulnerabilityDB(models.Model):
    vulnerabilityname = models.CharField(max_length=300)
    vulnerabilityseverity = models.CharField(max_length=300)
    vulnerabilitydescription = RichTextUploadingField()
    vulnerabilitysolution = RichTextUploadingField()
    vulnerabilityreferlnk = RichTextUploadingField(blank=True,null=True)
    cvssscore = models.FloatField(blank=True,null=True)
    cvssvector = models.CharField(max_length=300,default=None,null=True)



