

from django.urls import path
from . import views

urlpatterns = [
    path('', views.vulerabilitiydb, name='index'),
    path('add', views.vulerabilitiydbadd, name='add'),
    path('edit/<str:pk>/', views.vulerabilitiydbedit, name='edit'),
    path('delete/<str:pk>/', views.vulerabilitiydbdelete, name='edit'),
    
]

